# Reddit usernames

This project's soul purpose is to find free usernames on [reddit](https://www.reddit.com/).

## Getting Started

1. Clone the repository
2. Initate a RedditSession object (reddit_session.py) and use the is_username_free(username) function to check whether 
or not a username is free
3. Take a look at the example scripts for nice examples!


### Prerequisites

In order to run the program you will need to install [python 2.7](https://www.python.org/getit/)
(Add libraries)



## Development Process
The development process consisted of a research stage and a development stage.

## Authors

* **Yoad Ravid** - *Development* - [yoavravid](https://github.com/yoavravid)
* **Steven Dashevsky** - *Mentoring* - [Steven17D](https://github.com/Steven17D)

See also the list of [contributors](https://github.com/yoavravid/reddit_usernames/contributors) who participated in this project.

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details

## Acknowledgments

* Inspired by this [reddit post](https://www.reddit.com/r/learnprogramming/comments/8m8hl3/python_script_to_look_for_free_username_on_a/)
